@@ -6,7 +6,6 @@
 
 #define ADVERTISE_IP	"230.3.3.3"
 #define ADVERTISE_PORT	59000
-#define FTRANSFER_PORT	59001
 #define SERVER_IP	"127.0.0.1"
 #define SERVER_PORT	50000
 #define DEFAULT_IP	"231.0.0."
@@ -15,10 +14,11 @@
 #define MAXCON		16
 #define MAXCLIENT	255
 #define EMPTY		MAXCLIENT
-#define IDLENGTH	16
+#define IDLENGTH	32
 #define LOCKTIME	10
 #define CALC_INTERVAL	3000		/* calcrate_interval */
 #define RESEND_INTERVAL	10000		/* resend_interval */
+#define TRYCOUNT	3
 
 #define ROW_MAX		4
 #define COLUMN_MAX	4
@@ -28,14 +28,11 @@
 #define WINDOW_HEIGHT	600
 #define EXWINDOW_WIDTH	600
 #define EXWINDOW_HEIGHT 400
-#define CONFIG_FILE	"/etc/multivnc/multivnc_server.conf"
+#define CONFIG_FILE	"/etc/multivnc/server.conf"
 #define CAST_PK_SIZE	1400
 #define INPUT_PRIORITY	120
 #define STRLENGTH	64
-// save to *.swf file (recorded file) in this directory
-// char limit is IDLENGTH * 2 = 32 char
-#define REC_PATH	"/tmp/"
-#define SWF_DATA	1024
+#define IF_LENGTH   16  // interface name and ip length
 #define SLEEP		2
 
 #define START		1
@@ -65,7 +62,14 @@
 #define RECVSTATE	0x40	/* ۿμ */
 #define LOCKSTATE	0x80	/* å */
 
-#if 1
+/* ˤ륯饤ȥơ */
+#define NORMAL      0
+#define FREEZE      1
+#define IRREGULAR   2
+#define CHAOS       3
+#define NOSTAT      255
+
+
 /* for server */
 #define GETLOCK(Num)		(server_CB.client_grp[(Num)]->state & LOCKSTATE)?1:0
 #define SETLOCK(Num, Flag)	(Flag)?(server_CB.client_grp[(Num)]->state |= LOCKSTATE):\
@@ -107,7 +111,6 @@
 #define GETFILE_C		(client_CB.state & FILESTATE)?1:0
 #define SETFILE_C(Flag)		(Flag)?(client_CB.state |= FILESTATE):(client_CB.state &= ~FILESTATE)
 
-#endif
 
 typedef struct {
 	CARD8	type;
@@ -172,6 +175,33 @@ typedef struct {
 	CARD8 flag;
 } VncConnAdv;
 
+#if IMAGE_PROC
+typedef struct {
+  CARD8 type;
+  CARD8 flag;
+  CARD8 status;
+  CARD8 padding;
+  CARD32 histogram_h[256];
+  CARD32 histogram_s[256];
+  CARD32 histogram_v[256];
+} HistogramAdv;
+
+typedef struct {
+	CARD8 type;
+	CARD8 flag;
+} HistogramRequestAdv;
+#endif
+
+typedef struct {
+	CARD8 type;
+	CARD8 flag;
+} HelpAdv;
+
+typedef struct {
+	CARD8 type;
+	CARD8 flag;
+} HelpSetAdv;
+
 struct server_cb {
 	struct client_grp *client_grp[MAXCLIENT];	/* 饤Ⱦ */
 	CARD32 advertise_ip;				/* еưΥɥ쥹 */
@@ -215,6 +245,12 @@ struct client_grp {
 	gint resend_tag;
 	int shm_id;
 	FILE *fp;
+//#if IMAGE_PROC /* Ū˲ */
+    CARD8 client_status;
+    CARD32 histogram_h[256];
+    CARD32 histogram_s[256];
+    CARD32 histogram_v[256];
+//#endif
 };
 
 struct client_cb {
@@ -239,12 +275,18 @@ struct client_cb {
 	rfbServerInitMsg serverInitMsg;
 	rfbPixelFormat serverFormat;
 	CARD16 del_pk_num;				/* ˴줿ѥåȿ */
+#if IMAGE_PROC
+    CARD8 client_status;
+    CARD32 histogram_h[256];
+    CARD32 histogram_s[256];
+    CARD32 histogram_v[256];
+#endif
 };
 
 struct Draw_Info {
         int row;
         int column;
-	char group_name[16];
+	char group_name[IDLENGTH];
         int client_num[TABGROUP_MAX];
 };
 
@@ -278,7 +320,8 @@ extern void resendCallback (gpointer cnum);
 
 /* sockets.c */
 extern gint gdksock;
-extern int buffered;
+//extern int buffered;
+static int buffered = 0;
 
 /* vncviewer.c */
 extern int vnc_main(int argc, char **argv);
@@ -333,6 +376,9 @@ struct Shm_asym {
 
 extern void calcRateCallback (gpointer cnum);
 
+/* sc_common.c */
+int get_ifaddr(char *interface, char *addr);
+
 
 /* init_client.c */
 void DesktopInitForClient(void);
@@ -354,6 +400,9 @@ void makeTable( int p, int x, int y );
 void ChangeLabel(int p, int d, char *name);
 extern int exDB_flag;
 extern int Resend_flag;
+extern GtkWidget *user_list[TAB_MAX];
+extern GtkWidget *client_name_list[TAB_MAX][ROW_MAX * COLUMN_MAX];
+extern GtkWidget *group_name_list[TAB_MAX];
 
 /* callbacks.c(server) */
 GdkPixmap *gdkpixmap[TAB_MAX][ROW_MAX * COLUMN_MAX];
@@ -361,6 +410,7 @@ GtkWidget *drawingarea_ex;
 GdkPixmap *pixmap_ex;
 GdkImage *smallimage_ex;
 extern GtkWidget *window_ex;
+gboolean set_client_color (int page, int area);
 
 /* main.c(client) */
 extern GtkIMContext *im_context;
@@ -383,3 +433,29 @@ extern GtkWidget* create_dialog_inputmiss (void);
 extern GtkWidget* create_dialog_exit (void);
 
 #endif
+
+/*
+ * Standard gettext macros.
+ */
+#ifdef ENABLE_NLS
+#  include <libintl.h>
+#  undef _
+#  define _(String) dgettext (PACKAGE, String)
+#  define Q_(String) g_strip_context ((String), gettext (String))
+#  ifdef gettext_noop
+#    define N_(String) gettext_noop (String)
+#  else
+#    define N_(String) (String)
+#  endif
+#else
+#  define textdomain(String) (String)
+#  define gettext(String) (String)
+#  define dgettext(Domain,Message) (Message)
+#  define dcgettext(Domain,Message,Type) (Message)
+#  define bindtextdomain(Domain,Directory) (Domain)
+#  define _(String) (String)
+#  define Q_(String) g_strip_context ((String), (String))
+#  define N_(String) (String)
+#endif
+
+
