@@ -268,6 +268,8 @@ typedef struct {
 #define rfbFileAdv		14
 #define rfbClientAdv		15
 #define rfbClientExist		16
+#define rfbHistogramAdv		18
+#define rfbHelpAdv		20
 
 /* client -> server */
 #define rfbSetPixelFormat	0
@@ -285,6 +287,7 @@ typedef struct {
 #define rfbLockAdv		12
 #define rfbRecAdv		13
 #define rfbVncConnAdv		17
+#define rfbHistogramRequestAdv	19
 
 
 /*****************************************************************************
