@@ -32,6 +32,7 @@ extern Display *dpy;
 extern gboolean modifierPressed[16];
 extern GtkWidget *table[];
 extern GtkWidget *namelabel[][ROW_MAX * COLUMN_MAX];
+extern GtkWidget *main_window;
 
 int tab_num_tmp;
 int dialog_viewset_page, dialog_viewset_area;
@@ -45,6 +46,11 @@ GtkWidget *dialog_viewset_listviewport[TAB_MAX];
 GtkWidget *dialog_viewset_list[TAB_MAX];
 extern GtkWidget *dialog_viewset_viewport;
 extern IMAGEINFO *iinfo_ex;
+extern GtkWidget *client_name_list[TAB_MAX][ROW_MAX * COLUMN_MAX];
+extern GtkWidget *group_name_list[TAB_MAX];
+extern GtkWidget *frame[TAB_MAX][ROW_MAX * COLUMN_MAX];
+extern GtkWidget *user_list[TAB_MAX];
+extern GtkWidget *client_name_list[TAB_MAX][ROW_MAX * COLUMN_MAX];
 
 GtkWidget *window_ex;
 extern int exwindowWidth, exwindowHeight;
@@ -66,7 +72,7 @@ GtkWidget *dialog_send_comboboxentry2;
 char fullscreen_flag;
 
 extern GtkWidget *dialog_IDinput;
-char server_name[IDLENGTH];
+extern char server_name[IDLENGTH];
 
 GtkWidget *dialog_lock;
 GtkWidget *dialog_lock_table;
@@ -416,7 +422,7 @@ on_dialog_IDinput_buttonOK_clicked     (GtkButton       *button,
                                         gpointer         user_data)
 {
   //printf("ID Length: %d\n", strlen(server_name));
-  if (strlen(server_name) < 1) return -1;
+  if (strlen(server_name) < 1) return ;
 //  strcpy((char *)server_CB.server_ID, server_name);
   memcpy((char *)server_CB.server_ID, server_name, IDLENGTH);
   gtk_grab_remove(dialog_IDinput);
@@ -589,6 +595,8 @@ on_dialog_viewset_buttonOK_clicked             (GtkButton       *button,
   int pCnt, dCnt, num;
   int oldareamax, newareamax;
 
+  GtkWidget *hbox_ulist;
+
   tab_num = tab_num_tmp;
   for (pCnt = 0; pCnt < tab_num; pCnt++) {
     strcpy(draw_info[pCnt].group_name, gtk_editable_get_chars(GTK_EDITABLE(dialog_viewset_entry[pCnt]), 0, -1));
@@ -597,11 +605,17 @@ on_dialog_viewset_buttonOK_clicked             (GtkButton       *button,
     draw_info[pCnt].row = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(dialog_viewset_spinbutton_row[pCnt]));
     draw_info[pCnt].column = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(dialog_viewset_spinbutton_col[pCnt]));
     newareamax = draw_info[pCnt].row * draw_info[pCnt].column;
+
+    // 桼κ //
+    hbox_ulist = lookup_widget(GTK_WIDGET(main_window), "hbox_ulist");
+    gtk_container_remove(GTK_CONTAINER(hbox_ulist), user_list[pCnt]);
+
     for (dCnt = 0; dCnt < TABGROUP_MAX; dCnt++) {
       if (dCnt < oldareamax) {
 	if (table[pCnt] != NULL) {
           gtk_container_remove(GTK_CONTAINER(table[pCnt]), namelabel[pCnt][dCnt]);
-          gtk_container_remove(GTK_CONTAINER(table[pCnt]), drawingarea[pCnt][dCnt]);
+          gtk_container_remove(GTK_CONTAINER(frame[pCnt][dCnt]), drawingarea[pCnt][dCnt]);
+          gtk_container_remove(GTK_CONTAINER(table[pCnt]), frame[pCnt][dCnt]);
 	}
       }
       num = dialog_viewset_clientnum[pCnt][dCnt];
@@ -644,7 +658,7 @@ void
 on_dialog_viewset_button_tab_clicked          (GtkButton       *button,
 					       gpointer         user_data)
 {
-  char g_name[16];
+  char g_name[IDLENGTH];
 
   if (tab_num_tmp == TAB_MAX) return;
   sprintf(g_name, "group%d", tab_num_tmp+1);
@@ -1261,7 +1275,7 @@ on_screen_send_activate                (GtkMenuItem     *menuitem,
     on_send_activate(menuitem, NULL);
     gtk_entry_set_text (GTK_ENTRY (GTK_BIN(dialog_send_comboboxentry1)->child), _(draw_info[p].group_name));
     gtk_entry_set_text (GTK_ENTRY (GTK_BIN(dialog_send_comboboxentry2)->child),
-		        _((char *)server_CB.client_grp[draw_info[p].client_num[d]]->client_ID));
+		        (char *)server_CB.client_grp[draw_info[p].client_num[d]]->client_ID);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dialog_send_checkbutton2[p][d]), FALSE);
     gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (dialog_send_checkbutton2[p][d]), TRUE);
     if (strcmp((char *)server_CB.client_grp[draw_info[p].client_num[d]]->client_ID, (char *)server_CB.server_ID) != 0)
@@ -1519,7 +1533,7 @@ GtkWidget *makeTable_userList(void)
     /* Ŀcheck button κ */
     for (dCnt = 0; dCnt < TABGROUP_MAX; dCnt++) {
       if ((c_num = draw_info[pCnt].client_num[dCnt]) == EMPTY) continue;
-      dialog_send_checkbutton2[pCnt][dCnt] = gtk_check_button_new_with_mnemonic (_((char *)server_CB.client_grp[c_num]->client_ID));
+      dialog_send_checkbutton2[pCnt][dCnt] = gtk_check_button_new_with_mnemonic ((char *)server_CB.client_grp[c_num]->client_ID);
       gtk_widget_show (dialog_send_checkbutton2[pCnt][dCnt]);
       gtk_box_pack_start(GTK_BOX(vbox[pCnt]), dialog_send_checkbutton2[pCnt][dCnt], TRUE, TRUE, 0);
     }
@@ -1559,7 +1573,7 @@ GtkWidget *makeTable_send_state(void)
       }
 
       /* ֤ꤹ뤿check buttonκ */
-      dialog_send_checkbutton3[castnum] = gtk_check_button_new_with_mnemonic (_((char *)server_CB.client_grp[src_num]->client_ID));
+      dialog_send_checkbutton3[castnum] = gtk_check_button_new_with_mnemonic ((char *)server_CB.client_grp[src_num]->client_ID);
       gtk_widget_show (dialog_send_checkbutton3[castnum]);
       gtk_table_attach (GTK_TABLE (table), dialog_send_checkbutton3[castnum], 0, 1, 2*mcCnt, 2*mcCnt+1,
 		        (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
@@ -1583,7 +1597,7 @@ GtkWidget *makeTable_send_state(void)
   for (dstCnt = 0; dstCnt < MAXCLIENT; dstCnt++) {
     if (server_CB.client_grp[dstCnt] == NULL) continue;
     if ((server_CB.client_grp[dstCnt]->recv_grp != EMPTY)) {
-      dialog_send_checkbutton4[dstCnt] = gtk_check_button_new_with_mnemonic (_((char *)server_CB.client_grp[dstCnt]->client_ID));
+      dialog_send_checkbutton4[dstCnt] = gtk_check_button_new_with_mnemonic ((char *)server_CB.client_grp[dstCnt]->client_ID);
       gtk_widget_show (dialog_send_checkbutton4[dstCnt]);
       gtk_box_pack_start(GTK_BOX(vbox[server_CB.client_grp[dstCnt]->recv_grp]), dialog_send_checkbutton4[dstCnt], TRUE, TRUE, 0);
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dialog_send_checkbutton4[dstCnt]), GETRECV(dstCnt));
@@ -1730,7 +1744,7 @@ on_dialog_send_comboboxentry1_changed      (GtkComboBox     *combobox,
 	if (num == EMPTY) continue;
 	if (!GETSEND(num)) {
 	  gtk_combo_box_append_text (GTK_COMBO_BOX (dialog_send_comboboxentry2),
-				     _((char *)server_CB.client_grp[num]->client_ID));
+				     (char *)server_CB.client_grp[num]->client_ID);
 	}
       }
       return;
@@ -2220,3 +2234,82 @@ on_dialog_notify_okbutton_clicked      (GtkButton       *button,
 }
 
 
+gboolean
+on_frame_ulist_press_event             (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data)
+{
+
+  /* 桼ǥ֥륯å줿ν */
+  if (event->type == GDK_2BUTTON_PRESS) {
+    g_print("button press\n");
+  }
+  return TRUE;
+}
+
+gboolean set_client_color (int page, int area)
+{
+  char *color_name;
+  int client_no;
+  GdkColor color;
+
+  if ((page < 0) || (TAB_MAX < page) || (area < 0) || (TABGROUP_MAX < area)) {
+    printf("invalid page: %d, area:%d\n", page, area);
+    return FALSE;
+  }
+
+  color_name = (char*) malloc(32*sizeof(char));
+  memset(color_name, 0, 32*sizeof(char));
+
+  client_no = draw_info[page].client_num[area];
+  if(client_no == EMPTY) {
+    printf("not set color: no user\n");
+    memcpy(color_name, "SlateGray", 9);
+    gdk_color_parse(color_name, &color);
+    gtk_widget_modify_fg(GTK_WIDGET(client_name_list[page][area]), GTK_STATE_NORMAL, &color);
+    gtk_widget_modify_bg(GTK_WIDGET(frame[page][area]), GTK_STATE_NORMAL, NULL);
+    free(color_name);
+    return FALSE;
+  }
+
+  switch (server_CB.client_grp[client_no]->client_status) {
+    case NOSTAT:
+    case NORMAL:
+      gtk_widget_modify_bg(GTK_WIDGET(frame[page][area]), GTK_STATE_NORMAL, NULL);
+      memcpy(color_name, "black", 5);
+      gdk_color_parse(color_name, &color);
+      gtk_widget_modify_fg(GTK_WIDGET(client_name_list[page][area]), GTK_STATE_NORMAL, &color);
+      free(color_name);
+      return TRUE;
+      break;
+    case FREEZE:
+      memcpy(color_name, "blue", 4);
+      break;
+    case IRREGULAR:
+      memcpy(color_name, "red", 3);
+      break;
+    case CHAOS:
+      memcpy(color_name, "yellow", 6);
+      break;
+    default:
+      free(color_name);
+      printf("no set color\n");
+      return FALSE;
+  }
+
+  g_print("color:%s\n", color_name);
+  // set frame color //
+  gdk_color_parse(color_name, &color);
+  gtk_widget_modify_bg(GTK_WIDGET(frame[page][area]), GTK_STATE_NORMAL, &color);
+
+  // set label color of user list //
+  if (!strncmp(gtk_label_get_text(GTK_LABEL(client_name_list[page][area])), "no client", 9)) {
+    memcpy(color_name, "SlateGray", 9);
+    g_print("noclient-color:%s\n", color_name);
+  }
+  gdk_color_parse(color_name, &color);
+  gtk_widget_modify_fg(GTK_WIDGET(client_name_list[page][area]), GTK_STATE_NORMAL, &color);
+
+  free(color_name);
+  return TRUE;
+}
