@@ -144,6 +144,10 @@ void
 on_screen_send_stop_activate           (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
+void
+on_screen_record_activate              (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
 void
 on_dialog_send_checkbutton1_toggled    (GtkToggleButton *togglebutton,
 		                        gpointer         user_data);
@@ -332,3 +336,209 @@ void
 on_dialog_send_window_radiobutton_toggled
                                         (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
+
+gboolean
+on_window_ex_delete_event              (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data);
+
+gboolean
+on_window_ex_key_press_event           (GtkWidget       *widget,
+                                        GdkEventKey     *event,
+                                        gpointer         user_data);
+
+gboolean
+on_window_ex_key_release_event         (GtkWidget       *widget,
+                                        GdkEventKey     *event,
+                                        gpointer         user_data);
+
+gboolean
+on_window_ex_focus_out_event           (GtkWidget       *widget,
+                                        GdkEventFocus   *event,
+                                        gpointer         user_data);
+
+void
+on_window_ex_togglebutton_toggled      (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+gboolean
+on_drawingarea_ex_button_press_event   (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_drawingarea_ex_button_release_event (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_drawingarea_ex_configure_event      (GtkWidget       *widget,
+                                        GdkEventConfigure *event,
+                                        gpointer         user_data);
+
+gboolean
+on_drawingarea_ex_expose_event         (GtkWidget       *widget,
+                                        GdkEventExpose  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_drawingarea_ex_motion_notify_event  (GtkWidget       *widget,
+                                        GdkEventMotion  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_aspectframe_configure_event         (GtkWidget       *widget,
+                                        GdkEventConfigure *event,
+                                        gpointer         user_data);
+
+gboolean
+on_aspectframe_expose_event            (GtkWidget       *widget,
+                                        GdkEventExpose  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_drawingarea_ex_button_press_event   (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_drawingarea_ex_button_release_event (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_drawingarea_ex_configure_event      (GtkWidget       *widget,
+                                        GdkEventConfigure *event,
+                                        gpointer         user_data);
+
+gboolean
+on_drawingarea_ex_expose_event         (GtkWidget       *widget,
+                                        GdkEventExpose  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_drawingarea_ex_motion_notify_event  (GtkWidget       *widget,
+                                        GdkEventMotion  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_aspectframe_configure_event         (GtkWidget       *widget,
+                                        GdkEventConfigure *event,
+                                        gpointer         user_data);
+
+gboolean
+on_aspectframe_expose_event            (GtkWidget       *widget,
+                                        GdkEventExpose  *event,
+                                        gpointer         user_data);
+
+void
+on_spinbutton_rec_time_editing_done    (GtkCellEditable *celleditable,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_button_ok_clicked        (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_button_cancel_clicked    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_button_apply_clicked     (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_dialog_record_delete_event          (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data);
+
+void
+on_item_rec_activate                   (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_screen_record_activate              (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+gboolean
+on_dialog_notice_delete_event          (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data);
+
+void
+on_okbutton1_clicked                   (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_notify_okbutton_clicked      (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_record_checkbutton0_toggled  (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_dialog_lock_checkbutton0_toggled    (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_button_clicked           (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_button_close_clicked     (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_stop_button_clicked          (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_close_button_clicked         (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_stop_button_clicked      (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_close_button_clicked     (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_start_button_clicked     (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_button_clicked           (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_spinbutton_fps_editing_done         (GtkCellEditable *celleditable,
+                                        gpointer         user_data);
+
+void
+on_combo_entry1_editing_done           (GtkCellEditable *celleditable,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_start_button_clicked     (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_stop_button_clicked      (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_dialog_rec_close_button_clicked     (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_dialog_record_delete_event          (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data);
+
+gboolean
+on_frame_ulist_press_event             (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
