@@ -70,6 +70,14 @@ doListen()
   /* discard any X events */
   while( XCheckIfEvent( d, &ev, AllXEventsPredicate, NULL ));
 
+#if IMAGE_PROC
+  /* thread mutex initialize */
+  pthread_mutex_init (&i_mutex, NULL);
+
+  /* Create thread */
+  pthread_create (&i_thread, NULL, (void *)image_proc_server, (void *)&server_CB);
+#endif
+
   lock_start_time = time(NULL);
   while( True ){
     gtk_main_iteration();
@@ -101,8 +109,8 @@ listensockReadyCallback (gpointer clientData, gint fd, GdkInputCondition conditi
   //gdk_input_remove(server_CB.g_lsndsp);
 
   /* add control socket */
-  tmpdsp = accept(server_CB.lsndsp, (struct sockaddr*)&client_addr, &addrlen);
-  if (tmpdsp == -1) {
+  tmpdsp = accept(server_CB.lsndsp, (struct sockaddr*)&client_addr, (socklen_t *)&addrlen);
+  if (tmpdsp < 0) {
     printf("listensockReadyCallback : accept error.\n");
     exit(1);
   }
@@ -111,12 +119,15 @@ listensockReadyCallback (gpointer clientData, gint fd, GdkInputCondition conditi
   for (cnum = 0; cnum < MAXCLIENT; cnum++) {
     if (server_CB.client_grp[cnum] == NULL) continue;
     if (memcmp(&server_CB.client_grp[cnum]->client_ip, &client_addr.sin_addr, sizeof(CARD32)) == 0) {
-      if ((server_CB.client_grp[cnum]->vncdsp == 0) && (server_CB.client_grp[cnum]->ctldsp != 0)) {
+      if ((server_CB.client_grp[cnum]->vncdsp == 0) && (server_CB.client_grp[cnum]->ctldsp != -1)) {
         /* ctl connection only */
         break;
-      } else if ((server_CB.client_grp[cnum]->vncdsp != 0) && (server_CB.client_grp[cnum]->ctldsp != 0)){
+      } else if ((server_CB.client_grp[cnum]->vncdsp != 0) && (server_CB.client_grp[cnum]->ctldsp != -1)){
         /* Already connect */
-        server_CB.g_lsndsp = gdk_input_add_priority (server_CB.lsndsp, GDK_INPUT_READ, \
+	char dummybuf[MAXBUF];
+	while (read(tmpdsp, dummybuf, MAXBUF) == MAXBUF);
+	close(tmpdsp);
+	//server_CB.g_lsndsp = gdk_input_add_priority (server_CB.lsndsp, GDK_INPUT_READ, \
 	    				    (GdkInputFunction)listensockReadyCallback, NULL, INPUT_PRIORITY);
 	return;
       }
@@ -145,7 +156,7 @@ listensockReadyCallback (gpointer clientData, gint fd, GdkInputCondition conditi
     ConnectCTL(client_addr, tmpdsp, cnum);
     /* increment user number */
     server_CB.user_num++;
-  } else if ((server_CB.client_grp[cnum]->vncdsp == 0) && (server_CB.client_grp[cnum]->ctldsp != 0)) {
+  } else if ((server_CB.client_grp[cnum]->vncdsp == 0) && (server_CB.client_grp[cnum]->ctldsp != -1)) {
     ConnectVNC(client_addr, tmpdsp, cnum);
     if ((exDB_flag) && (!chStateDB(cnum, 1))) {
       fprintf(stderr, "Can't Connect DB Server.\n");
@@ -256,7 +267,8 @@ getFlashFont(Display *d)
   char **fontNames;
   int nFontNames;
 
-  sprintf(fontName,"-*-courier-bold-r-*-*-%d-*-*-*-*-*-iso8859-1",
+//  sprintf(fontName,"-*-courier-bold-r-*-*-%d-*-*-*-*-*-iso8859-1",
+  sprintf(fontName,"-*-*-bold-r-*-*-%d-*-*-*-*-*-iso8859-1",
 	  FLASHWIDTH);
   fontNames = XListFonts(d, fontName, 1, &nFontNames);
   if (nFontNames == 1) {
