@@ -26,7 +26,6 @@ static void vncSocketCallback(gpointer clientData, gint fd, GdkInputCondition co
 static Bool CheckDrawingarea(int);
 static Bool DiscoverDrawingarea(int);
 void CheckLockClient(void);
-extern char *swf_file;
 
 int getClientFromCtldsp (int fd);
 int getClientFromVncdsp (int fd);
@@ -40,7 +39,10 @@ extern GtkWidget *main_window;
 GtkWidget *dialog_IDinput;
 
 //extern GtkWidget *dialog_record;
+//extern char *swf_file;
 
+extern char interface_addr[IF_LENGTH];
+extern char server_name[IDLENGTH];
 
 /* shared memory */
 long *shm_sec;
@@ -145,7 +147,8 @@ ConnectAdv ()
   bzero(&self, sizeof(struct sockaddr_in));
   self.sin_family = AF_INET;
   self.sin_port = server_CB.server_port;
-  self.sin_addr.s_addr = INADDR_ANY;
+//  self.sin_addr.s_addr = INADDR_ANY;
+  self.sin_addr.s_addr = inet_addr(interface_addr);
 
   /* Assign a port number to the socket */
   if (bind(sockfd, (struct sockaddr*)&self, sizeof(self)) != 0) {
@@ -189,11 +192,16 @@ AdvInit ()
   char low_ip[4];
 
   bzero(&server_CB, sizeof(struct server_cb));
-  /* Input Server_ID */
-  dialog_IDinput = (GtkWidget *)create_dialog_IDinput();
-  gtk_widget_show(dialog_IDinput);
-  gtk_grab_add(dialog_IDinput);
-  gtk_main();
+  if (strlen(server_name) == 0) {
+    /* Input Server_ID */
+    dialog_IDinput = (GtkWidget *)create_dialog_IDinput();
+    gtk_widget_show(dialog_IDinput);
+    gtk_grab_add(dialog_IDinput);
+    gtk_main();
+  } else {
+    memcpy((char *)server_CB.server_ID, server_name, IDLENGTH);
+    printf("server id: %s (%s)\n", server_CB.server_ID, server_name);
+  }
   server_CB.server_port = htons(SERVER_PORT);
   server_CB.advertise_ip = inet_addr(ADVERTISE_IP);
   server_CB.advertise_port = htons(ADVERTISE_PORT);
@@ -217,10 +225,13 @@ AdvInit ()
 int
 ConnectMyself ()
 {
-  char tmp[256] = "multivnc_client -d 1 --nonotice -u ";
+  char tmp[256] = "multivnc_client -d 1 -i lo --nonotice -u ";
   strcat (tmp, (char *)server_CB.server_ID);
   strcat (tmp, " -s ");
   strcat (tmp, (char *)server_CB.server_ID);
+#if IMAGE_PROC
+  strcat (tmp, " -q ");
+#endif
   strcat (tmp, " &");
   printf("tmp=%s\n",tmp);
 
@@ -234,6 +245,9 @@ ConnectCTL (struct sockaddr_in client_addr, int ctldsp, int cnum)
   printf("cnum=%d\n",cnum);
   server_CB.client_grp[cnum] = malloc(sizeof(struct client_grp));
   bzero(server_CB.client_grp[cnum], sizeof(struct client_grp));
+#if IMAGE_PROC
+  server_CB.client_grp[cnum]->client_status = NOSTAT;
+#endif
   server_CB.client_grp[cnum]->ctldsp = ctldsp;
   server_CB.client_grp[cnum]->client_ip = client_addr.sin_addr.s_addr;
   server_CB.client_grp[cnum]->client_port = client_addr.sin_port;
@@ -432,9 +446,14 @@ controlSocketCallback (gpointer clientData, gint fd, GdkInputCondition condition
   if (clientNum == EMPTY) return;
   gdk_input_remove(server_CB.client_grp[clientNum]->g_ctldsp);
   int socket = server_CB.client_grp[clientNum]->ctldsp;
+#if IMAGE_PROC
+  char buf[4096];
+  bzero (buf, 4096);
+#else
   char buf[64];
-
   bzero (buf, 64);
+#endif
+
   if (recv (socket, buf, 2, 0) <= 0) {
     printf("session closed\n");
 
@@ -500,7 +519,7 @@ controlSocketCallback (gpointer clientData, gint fd, GdkInputCondition condition
       memcpy (server_CB.client_grp[clientNum]->client_ID, buf, IDLENGTH);
       printf("Client : %s\n",server_CB.client_grp[clientNum]->client_ID);
       fprintf(stderr, "Control packet receive\n");
-      
+
       /* Database Authentication */
       SendAllowMsg (clientNum, buf);
       break;
@@ -588,11 +607,18 @@ controlSocketCallback (gpointer clientData, gint fd, GdkInputCondition condition
 
 #endif
 
+#if IMAGE_PROC
+    case rfbHistogramAdv:
+      GetHistogram(clientNum, buf, socket);
+      break;
+#endif
+
     default:
-      perror("Unknown Message Type");
+      err("Unknown Message Type");
       printf("client:%d, type %d\n", clientNum, buf[0]);
       break;
   } 
+  set_client_color (server_CB.client_grp[clientNum]->draw_page, server_CB.client_grp[clientNum]->draw_area);
   server_CB.client_grp[clientNum]->g_ctldsp = gdk_input_add_priority (server_CB.client_grp[clientNum]->ctldsp,
 		        GDK_INPUT_READ, (GdkInputFunction)controlSocketCallback, NULL, INPUT_PRIORITY);
   return;
@@ -795,7 +821,15 @@ CreateMultiSockToSend (unsigned int ip, int port)
   adv.sin_addr.s_addr = ip;
 
   stMreq.imr_multiaddr.s_addr = adv.sin_addr.s_addr;
-  stMreq.imr_interface.s_addr = INADDR_ANY;
+//  stMreq.imr_interface.s_addr = INADDR_ANY;
+  stMreq.imr_interface.s_addr = inet_addr(interface_addr);
+
+  if (setsockopt(sockadv, IPPROTO_IP, IP_MULTICAST_IF, (char *) &stMreq.imr_interface.s_addr, sizeof(stMreq.imr_interface.s_addr)) < 0) {
+    fprintf(stderr, "%s : CreateMultiSockToSend : ip_multicast_if\n", programName);
+    close(sockadv);
+    exit (1);
+  }
+
 
   if (setsockopt(sockadv, IPPROTO_IP, IP_ADD_MEMBERSHIP, (char *) &stMreq, sizeof(stMreq)) < 0) {
     fprintf(stderr, "%s : CreateMultiSockToSend : ip_add_membership\n", programName);
